<?php
namespace PME\Controllers\Cardapio;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager\Doctrine\NameProvider;

class ConfiguracaoCardapio extends \PME\Services\TeknisaCrud {
    protected $crudService;
	protected $parameterBag;
	protected $dataSourceName;
	protected $connection;
	protected $newCode;
	protected $environment;
	protected $entityManager;

    public function __construct($crudService, $parameterBag, $connection, $newCode, $environment, $entityManager) {
        parent::__construct($crudService, $parameterBag);
        $this->connection = $connection;
        $this->newCode = $newCode;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
	}
	
	public function saveConfigCard(DTO\Request\Row $request, DTO\Response $response) {
	    $row = $request->getRow();
	    try {
	    	$this->connection->beginTransaction();
	    	foreach($row['editedRowsCard'] as $editedRows) {
	    		if ($editedRows['__is_new']) {
	    			$this->insertNewRegisterIntoConfiCard($row['filterData'], $editedRows);
	    		} else {
	    			$this->updatePlates($editedRows);
	    			$this->updateRegisterIntoConfiCard($editedRows);
	    		}
	    	}
	    	
	    	$this->connection->commit();
	    	$response->addDataSet(new DataSet("saveConfigCard", array(true)));
	    } catch (\Exception $e) {
	    	$this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function getMaxSeqConfCard(DTO\Request\Row $request, DTO\Response $response) {
		$sql = "SELECT MAX(NRSEQCNFCPME) AS NRSEQCNFCPME, MAX(NRORDCNFCPME) AS NRORDCNFCPME FROM CONFCARDPME WHERE NRCARDPME = :NRCARDPME AND CDSERVFILI = :CDSERVFILI AND CDFILCENTPME = :CDFILCENTPME";
		$row = $request->getRow();
		$paramSelect = array(
            "NRCARDPME"	    => $row['NRCARDPME'],
        	"CDSERVFILI"	=> $row['service']['CDSERVFILI'],
            "CDFILCENTPME"  => $row['cdfilcentpme']
        );
      
      $maxSeq = $this->entityManager->getConnection()->fetchAll($sql, $paramSelect);
      $response->addDataSet(new DataSet("maxSeq", $maxSeq));
	}
	
	private function insertNewRegisterIntoConfiCard($filterData, $row) {
		$insertConfig = "INSERT INTO CONFCARDPME (CDFILCENTPME, NRCARDPME, CDSERVFILI, NRSEQCNFCPME, CDTIPOPRAT, IDOPCCNFCPME, IDIMPCNFCPME, NRORDCNFCPME) VALUES (:CDFILCENTPME, :NRCARDPME, :CDSERVFILI, :NRSEQCNFCPME, :CDTIPOPRAT, :IDOPCCNFCPME, :IDIMPCNFCPME, :NRORDCNFCPME)";
		
		$params = array(
            "CDFILCENTPME"   => $filterData['cdfilcentpme'],
            "NRCARDPME"      => $filterData['NRCARDPME'],
            "CDSERVFILI"	 => $filterData['service']['CDSERVFILI'],
            "NRSEQCNFCPME"	 => $row['NRSEQCNFCPME'],
            "CDTIPOPRAT"	 => $row['DESCRICAO'], // DESCRICAO É O CDTIPOPRAT NO DRAGANDDROP QUE VAI SER ADD.
            "IDOPCCNFCPME"   => $row['IDOPCCNFCPME'],
            "IDIMPCNFCPME"   => $row['IDIMPCNFCPME'],
            "NRORDCNFCPME"	 => $row['NRORDCNFCPME']
        );
        
        $stmt = $this->connection->prepare($insertConfig);
    	$stmt->execute($params);
	}
	
	private function updatePlates($editedRows) {
		$tpPlates = $this->getTpPlateCardia($editedRows);
		$updatePlates = "UPDATE COMPCARDPME SET NRORDPRACPME = :NRORDCNFCPME WHERE CDFILCENTPME = :CDFILCENTPME AND NRCARDPME = :NRCARDPME AND NRCARDIAPME = :NRCARDIAPME AND NRSEQPRACPME = :NRSEQPRACPME AND CDTIPOPRAT = :CDTIPOPRAT";
		
		foreach($tpPlates as $plate) {
			$params = array(
				"NRORDCNFCPME"	=> $editedRows['NRORDCNFCPME'],
		        "CDFILCENTPME"  => $plate['CDFILCENTPME'],
	            "NRCARDPME"     => $plate['NRCARDPME'],
	            "NRCARDIAPME"   => $plate['NRCARDIAPME'],
	            "NRSEQPRACPME"	=> $plate['NRSEQPRACPME'],
	            "CDTIPOPRAT"	=> $plate['CDTIPOPRAT']
		    );
		    
		    $stmt = $this->connection->prepare($updatePlates);
			$stmt->execute($params);
		}
	}
	
	private function updateRegisterIntoConfiCard($row) {
		$updateConfig = "UPDATE CONFCARDPME SET NRORDCNFCPME = :NRORDCNFCPME, IDOPCCNFCPME = :IDOPCCNFCPME, IDIMPCNFCPME = :IDIMPCNFCPME WHERE CDFILCENTPME = :CDFILCENTPME AND NRCARDPME = :NRCARDPME AND CDSERVFILI = :CDSERVFILI AND NRSEQCNFCPME = :NRSEQCNFCPME AND CDTIPOPRAT = :CDTIPOPRAT";
		
		$params = array(
	        "CDFILCENTPME"   => $row['CDFILCENTPME'],
	        "NRCARDPME"      => $row['NRCARDPME'],
	        "CDSERVFILI"	 => $row['CDSERVFILI'],
	        "NRSEQCNFCPME"	 => $row['NRSEQCNFCPME'],
	        "CDTIPOPRAT"	 => $row['CDTIPOPRAT'],
	        "IDOPCCNFCPME"   => $row['IDOPCCNFCPME'],
	        "IDIMPCNFCPME"   => $row['IDIMPCNFCPME'],
	        "NRORDCNFCPME"	 => $row['NRORDCNFCPME']
	    );
	    
	    $stmt = $this->connection->prepare($updateConfig);
		$stmt->execute($params);
	}
	
	public function deleteConfCard(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		try {
			$this->connection->beginTransaction();
			foreach($row as $selectedRow) {
				$tpPlates = $this->getTpPlateCardia($selectedRow);
				if (count($tpPlates) > 0) $this->deleteTpPlates($tpPlates);
				$this->deleteRegisterConfigCard($selectedRow);
			}
			
			$this->connection->commit();
	    	$response->addDataSet(new DataSet("deleteConfigCard", array(true)));
		} catch (\Exception $e) {
	    	$this->connection->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	private function getTpPlateCardia($selectedRow) {
		$sql = "SELECT C.CDFILCENTPME, C.CDSERVFILI, C.NRCARDIAPME, C.NRCARDPME, P.NRSEQPRACPME, P.CDTIPOPRAT, P.NRORDPRACPME FROM CARDIAPME C, COMPCARDPME P, CARDAPIOPME CA WHERE C.CDFILCENTPME  = :P_CDFILCENTPME AND C.CDSERVFILI    = :P_CDSERVFILI   AND C.NRCARDPME     = :P_NRCARDPME    AND CA.DTINICARDPME = :P_DTINICARDPME AND CA.DTFINCARDPME = :P_DTFINCARDPME AND CA.CDTIPOCARD   = :P_CDTIPOCARD   AND P.CDFILCENTPME  = C.CDFILCENTPME  AND P.CDFILCENTPME  = CA.CDFILCENTPME AND P.NRCARDIAPME   = C.NRCARDIAPME   AND P.NRCARDPME     = C.NRCARDPME     AND C.NRCARDPME     = CA.NRCARDPME    AND P.NRSEQPRACPME  = :P_NRSEQ";
		
		$paramSelect = array(
	        "P_CDFILCENTPME"  => $selectedRow['CDFILCENTPME'],
	    	"P_CDSERVFILI"	  => $selectedRow['CDSERVFILI'],
	        "P_NRCARDPME"     => $selectedRow['NRCARDPME'],
	        "P_DTINICARDPME"  => $selectedRow['DTINICARDPME'],
	        "P_DTFINCARDPME"  => $selectedRow['DTFINCARDPME'],
	        "P_CDTIPOCARD"    => $selectedRow['CDTIPOCARD'],
	        "P_NRSEQ"         => $selectedRow['NRSEQCNFCPME']
	    );
	    
    	return $this->entityManager->getConnection()->fetchAll($sql, $paramSelect);
	}
	
	private function deleteTpPlates($tpPlates) {
		$delete = "DELETE FROM COMPCARDPME WHERE CDFILCENTPME = :CDFILCENTPME AND NRCARDPME = :NRCARDPME AND NRCARDIAPME = :NRCARDIAPME AND NRSEQPRACPME = :NRSEQPRACPME AND CDTIPOPRAT = :CDTIPOPRAT";
		
		foreach($tpPlates as $plate) {
			$params = array(
	            "CDFILCENTPME"  => $plate['CDFILCENTPME'],
	            "NRCARDPME"     => $plate['NRCARDPME'],
	            "NRCARDIAPME"   => $plate['NRCARDIAPME'],
	            "NRSEQPRACPME"	=> $plate['NRSEQPRACPME'],
	            "CDTIPOPRAT"	=> $plate['CDTIPOPRAT']
	        );	
	        
	        $stmt = $this->connection->prepare($delete);
	    	$stmt->execute($params);
		}
	}
	
	private function deleteRegisterConfigCard($selectedRow) {
		$delete = "DELETE FROM CONFCARDPME WHERE CDFILCENTPME = :OLD_CDFILCENTPME AND CDSERVFILI = :OLD_CDSERVFILI AND NRSEQCNFCPME = :OLD_NRSEQCNFCPME AND NRCARDPME = :OLD_NRCARDPME";
		
		$params = array(
            "OLD_CDFILCENTPME" => $selectedRow['CDFILCENTPME'],
            "OLD_CDSERVFILI"   => $selectedRow['CDSERVFILI'],
            "OLD_NRSEQCNFCPME" => $selectedRow['NRSEQCNFCPME'],
            "OLD_NRCARDPME"	   => $selectedRow['NRCARDPME']
        );	
        
        $stmt = $this->connection->prepare($delete);
    	$stmt->execute($params);
	}
}