<?php
namespace PME\Controllers\Relatorios;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class EmissaoCardSemanaController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $birtStrategy;
    protected $environment;
    protected $utilities;

    public function __construct(ReportService $reportService, $entityManager, $birtStrategy, $environment, $utilities) {
      $this->entityManager = $entityManager;
      $this->birtStrategy  = $birtStrategy;
      $this->environment   = $environment;
      $this->utilities     = $utilities;

      parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME01000' => 
        array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
              "IMPCOMENSAIS" => "P_IMPCOMENS",
              "CDFILIAL"     => "P_CDFILIAL",
              "NMFILIAGRE"   => "P_NMFILIAGRE",
              "QUEBRA"       => "P_QUEBRA",
              "TIPOCARD"     => "P_CDTIPOCARD",
              "CDFILCENTPME" => "P_CDFILCENTPME",
              "DTDE"         => "P_DTINICIAL",
              "DTATE"        => "P_DTFINAL",
              "SERVICO"      => "P_CDSERVFILI",
              "NRORG"        => "P_NRORG",
              "IMPMSG"       => "P_IMPMSG",
              "ORDENA"       => "P_ORDENA"
            )
        )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      $row = $request->getRow();
      $nrorg = $this->environment->getNrOrgTrab();

      if(empty($row['SERVICO'])) $row['SERVICO'] = 'T';
      else if(is_array($row['SERVICO'])) $row['SERVICO'] = join("_", $row['SERVICO']);
      
      if(empty($row['UNIDADE'])) $row['NMUNIDADE'] = null;
      else $row['NMUNIDADE'] = $row['UNIDADE']['CDFILIAL'].' '.$row['UNIDADE']['NMFILIAL'];

      if(empty($row['QUEBRA'])) $row['QUEBRA'] = 'N';
      else $row['QUEBRA'] = 'S';
      
      if(empty($row['IMPMSG'])) $row['IMPMSG'] = 'N';
      else {
        $row['QUEBRA'] = 'S';
        $row['IMPMSG'] = 'S';
      }
      
      $row['NRORG'] = $nrorg;
      
      $this->birtStrategy->setReportLocale($this->environment->getLanguage());
      $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
    }
}